@@ -76,6 +76,10 @@ const (
 
 	// HaTS is the HaTS Survey ID
 	HaTS = "hats"
+
+	// SubtaskIDNone is the value used for Event API messages when there is no
+	// corresponding subtask
+	SubtaskIDNone = "-1"
 )
 
 type Phase string
@@ -97,6 +101,9 @@ var (
 	// BuildContext is the absolute path to a directory this artifact is meant to be built from for custom artifacts
 	BuildContext = "BUILD_CONTEXT"
 
+	// SkipTest is Whether to skip the tests after building passing into a custom build script
+	SkipTest = "SKIP_TEST"
+
 	// KubeContext is the expected kubecontext to build an artifact with a custom build script on cluster
 	KubeContext = "KUBE_CONTEXT"
 
