@@ -17,6 +17,7 @@ limitations under the License.
 package analyze
 
 import (
+	"context"
 	"fmt"
 	"path/filepath"
 
@@ -31,7 +32,7 @@ type skaffoldConfigAnalyzer struct {
 	targetConfig string
 }
 
-func (a *skaffoldConfigAnalyzer) analyzeFile(filePath string) error {
+func (a *skaffoldConfigAnalyzer) analyzeFile(ctx context.Context, filePath string) error {
 	if !schema.IsSkaffoldConfig(filePath) || a.force || a.analyzeMode {
 		return nil
 	}
