@@ -39,6 +39,7 @@ var (
 		Builders:          map[string]int{},
 		BuildDependencies: map[string]int{},
 		SyncType:          map[string]bool{},
+		Hooks:             map[HookPhase]int{},
 		DevIterations:     []devIteration{},
 		StartTime:         time.Now(),
 		Version:           version.Get().Version,
@@ -86,14 +87,23 @@ func InitMeterFromConfig(configs []*latestV1.SkaffoldConfig, user string) {
 			if len(artifact.Dependencies) > 0 {
 				meter.BuildDependencies[yamltags.GetYamlTag(artifact.ArtifactType)]++
 			}
+			meter.Hooks[HookPhases.PreBuild] += len(artifact.LifecycleHooks.PreHooks)
+			meter.Hooks[HookPhases.PostBuild] += len(artifact.LifecycleHooks.PostHooks)
+
 			if artifact.Sync != nil {
 				meter.SyncType[yamltags.GetYamlTag(artifact.Sync)] = true
+				meter.Hooks[HookPhases.PreSync] += len(artifact.Sync.LifecycleHooks.PreHooks)
+				meter.Hooks[HookPhases.PostSync] += len(artifact.Sync.LifecycleHooks.PostHooks)
 			}
 		}
 		meter.Deployers = append(meter.Deployers, yamltags.GetYamlKeys(config.Deploy.DeployType)...)
 		if h := config.Deploy.HelmDeploy; h != nil {
 			meter.HelmReleasesCount = len(h.Releases)
 		}
+		if k := config.Deploy.KubectlDeploy; k != nil {
+			meter.Hooks[HookPhases.PreDeploy] += len(k.LifecycleHooks.PreHooks)
+			meter.Hooks[HookPhases.PostDeploy] += len(k.LifecycleHooks.PostHooks)
+		}
 		meter.BuildArtifacts += len(config.Pipeline.Build.Artifacts)
 	}
 	meter.PlatformType = strings.Join(platforms, ":")
