@@ -37,6 +37,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
 	kubernetesclient "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
@@ -84,7 +85,7 @@ func (k *KubectlForwarder) Forward(parentCtx context.Context, pfe *portForwardEn
 	return <-errChan
 }
 
-func (k *KubectlForwarder) forward(parentCtx context.Context, pfe *portForwardEntry, errChan chan error) {
+func (k *KubectlForwarder) forward(ctx context.Context, pfe *portForwardEntry, errChan chan error) {
 	if atomic.LoadInt32(&k.started) == 0 {
 		errChan <- fmt.Errorf("Forward() called before kubectl forwarder was started")
 		return
@@ -95,7 +96,7 @@ func (k *KubectlForwarder) forward(parentCtx context.Context, pfe *portForwardEn
 	for {
 		pfe.terminationLock.Lock()
 		if pfe.terminated {
-			logrus.Debugf("port forwarding %v was cancelled...", pfe)
+			log.Entry(ctx).Debugf("port forwarding %v was cancelled...", pfe)
 			pfe.terminationLock.Unlock()
 			errChan <- nil
 			return
@@ -116,7 +117,7 @@ func (k *KubectlForwarder) forward(parentCtx context.Context, pfe *portForwardEn
 			notifiedUser = false
 		}
 
-		ctx, cancel := context.WithCancel(parentCtx)
+		ctx, cancel := context.WithCancel(ctx)
 		pfe.cancel = cancel
 
 		args := portForwardArgs(ctx, k.kubectl.KubeContext, pfe)
@@ -125,14 +126,14 @@ func (k *KubectlForwarder) forward(parentCtx context.Context, pfe *portForwardEn
 		cmd.Stdout = &buf
 		cmd.Stderr = &buf
 
-		logrus.Debugf("Running command: %s", cmd.Args)
+		log.Entry(ctx).Debugf("Running command: %s", cmd.Args)
 		if err := cmd.Start(); err != nil {
 			if ctx.Err() == context.Canceled {
-				logrus.Debugf("couldn't start %v due to context cancellation", pfe)
+				log.Entry(ctx).Debugf("couldn't start %v due to context cancellation", pfe)
 				return
 			}
 			// Retry on exit at Start()
-			logrus.Debugf("error starting port forwarding %v: %s, output: %s", pfe, err, buf.String())
+			log.Entry(ctx).Debugf("error starting port forwarding %v: %s, output: %s", pfe, err, buf.String())
 			time.Sleep(500 * time.Millisecond)
 			continue
 		}
@@ -141,14 +142,14 @@ func (k *KubectlForwarder) forward(parentCtx context.Context, pfe *portForwardEn
 		go k.monitorLogs(ctx, &buf, cmd, pfe, errChan)
 		if err := cmd.Wait(); err != nil {
 			if ctx.Err() == context.Canceled {
-				logrus.Debugf("terminated %v due to context cancellation", pfe)
+				log.Entry(ctx).Debugf("terminated %v due to context cancellation", pfe)
 				return
 			}
 			// To make sure that the log monitor gets cleared up
 			cancel()
 
 			s := buf.String()
-			logrus.Debugf("port forwarding %v got terminated: %s, output: %s", pfe, err, s)
+			log.Entry(ctx).Debugf("port forwarding %v got terminated: %s, output: %s", pfe, err, s)
 			if !strings.Contains(s, "address already in use") {
 				select {
 				case errChan <- fmt.Errorf("port forwarding %v got terminated: output: %s", pfe, s):
@@ -172,7 +173,7 @@ func portForwardArgs(ctx context.Context, kubeContext string, pfe *portForwardEn
 			args = append(args, fmt.Sprintf("pod/%s", podName), fmt.Sprintf("%d:%d", pfe.localPort, remotePort))
 			break
 		}
-		logrus.Warnf("could not map pods to service %s/%s/%s: %v", pfe.resource.Namespace, pfe.resource.Name, pfe.resource.Port.String(), err)
+		log.Entry(ctx).Warnf("could not map pods to service %s/%s/%s: %v", pfe.resource.Namespace, pfe.resource.Name, pfe.resource.Port.String(), err)
 		fallthrough // and let kubectl try to handle it
 
 	default:
@@ -187,7 +188,7 @@ func portForwardArgs(ctx context.Context, kubeContext string, pfe *portForwardEn
 
 // Terminate terminates an existing kubectl port-forward command using SIGTERM
 func (*KubectlForwarder) Terminate(p *portForwardEntry) {
-	logrus.Debugf("Terminating port-forward %v", p)
+	log.Entry(context.TODO()).Debugf("Terminating port-forward %v", p)
 
 	p.terminationLock.Lock()
 	defer p.terminationLock.Unlock()
@@ -216,15 +217,15 @@ func (*KubectlForwarder) monitorLogs(ctx context.Context, logs io.Reader, cmd *k
 				continue
 			}
 
-			logrus.Tracef("[port-forward] %s", s)
+			log.Entry(ctx).Tracef("[port-forward] %s", s)
 
 			if strings.Contains(s, "error forwarding port") ||
 				strings.Contains(s, "unable to forward") ||
 				strings.Contains(s, "error upgrading connection") {
 				// kubectl is having an error. retry the command
-				logrus.Tracef("killing port forwarding %v", p)
+				log.Entry(ctx).Tracef("killing port forwarding %v", p)
 				if err := cmd.Terminate(); err != nil {
-					logrus.Tracef("failed to kill port forwarding %v, err: %s", p, err)
+					log.Entry(ctx).Tracef("failed to kill port forwarding %v, err: %s", p, err)
 				}
 				select {
 				case err <- fmt.Errorf("port forwarding %v got terminated: output: %s", p, s):
@@ -282,12 +283,12 @@ func findNewestPodForService(ctx context.Context, kubeContext, ns, serviceName s
 		for _, p := range pods {
 			names = append(names, fmt.Sprintf("(pod:%q phase:%v created:%v)", p.Name, p.Status.Phase, p.CreationTimestamp))
 		}
-		logrus.Tracef("service %s/%s maps to %d pods: %v", serviceName, servicePort.String(), len(pods), names)
+		log.Entry(ctx).Tracef("service %s/%s maps to %d pods: %v", serviceName, servicePort.String(), len(pods), names)
 	}
 
 	for _, p := range pods {
 		if targetPort := findTargetPort(svcPort, p); targetPort > 0 {
-			logrus.Debugf("Forwarding service %s/%s to pod %s/%d", serviceName, servicePort.String(), p.Name, targetPort)
+			log.Entry(ctx).Debugf("Forwarding service %s/%s to pod %s/%d", serviceName, servicePort.String(), p.Name, targetPort)
 			return p.Name, targetPort, nil
 		}
 	}
