@@ -128,10 +128,12 @@ func (t *TestBench) GetSyncer() sync.Syncer {
 func (t *TestBench) RegisterLocalImages(_ []graph.Artifact) {}
 func (t *TestBench) TrackBuildArtifacts(_ []graph.Artifact) {}
 
-func (t *TestBench) TestDependencies(*latestV1.Artifact) ([]string, error) { return nil, nil }
-func (t *TestBench) Dependencies() ([]string, error)                       { return nil, nil }
-func (t *TestBench) Cleanup(ctx context.Context, out io.Writer) error      { return nil }
-func (t *TestBench) Prune(ctx context.Context, out io.Writer) error        { return nil }
+func (t *TestBench) TestDependencies(context.Context, *latestV1.Artifact) ([]string, error) {
+	return nil, nil
+}
+func (t *TestBench) Dependencies() ([]string, error)                  { return nil, nil }
+func (t *TestBench) Cleanup(ctx context.Context, out io.Writer) error { return nil }
+func (t *TestBench) Prune(ctx context.Context, out io.Writer) error   { return nil }
 
 func (t *TestBench) enterNewCycle() {
 	t.actions = append(t.actions, t.currentActions)
@@ -258,6 +260,12 @@ func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor,
 	if autoTriggers == nil {
 		autoTriggers = &triggerState{true, true, true}
 	}
+	var tests []*latestV1.TestCase
+	for _, a := range artifacts {
+		tests = append(tests, &latestV1.TestCase{
+			ImageName: a.ImageName,
+		})
+	}
 	cfg := &latestV1.SkaffoldConfig{
 		Pipeline: latestV1.Pipeline{
 			Build: latestV1.BuildConfig{
@@ -267,6 +275,7 @@ func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor,
 				},
 				Artifacts: artifacts,
 			},
+			Test:   tests,
 			Deploy: latestV1.DeployConfig{StatusCheckDeadlineSeconds: 60},
 		},
 	}
@@ -282,12 +291,12 @@ func createRunner(t *testutil.T, testBench *TestBench, monitor filemon.Monitor,
 			AutoDeploy:        autoTriggers.deploy,
 		},
 	}
-	runner, err := NewForConfig(runCtx)
+	runner, err := NewForConfig(context.Background(), runCtx)
 	t.CheckNoError(err)
 
 	// TODO(yuwenma):builder.builder looks weird. Avoid the nested struct.
 	runner.Builder.Builder = testBench
-	runner.Tester = testBench
+	runner.tester = testBench
 	runner.deployer = testBench
 	runner.listener = testBench
 	runner.monitor = monitor
@@ -442,7 +451,9 @@ func TestNewForConfig(t *testing.T) {
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			t.SetupFakeKubernetesContext(api.Config{CurrentContext: "cluster1"})
-			t.Override(&cluster.FindMinikubeBinary, func() (string, semver.Version, error) { return "", semver.Version{}, errors.New("not found") })
+			t.Override(&cluster.FindMinikubeBinary, func(context.Context) (string, semver.Version, error) {
+				return "", semver.Version{}, errors.New("not found")
+			})
 			t.Override(&util.DefaultExecCommand, testutil.CmdRunWithOutput(
 				"helm version --client", `version.BuildInfo{Version:"v3.0.0"}`).
 				AndRunWithOutput("kubectl version --client -ojson", "v1.5.6"))
@@ -454,7 +465,7 @@ func TestNewForConfig(t *testing.T) {
 				},
 			}
 
-			cfg, err := NewForConfig(runCtx)
+			cfg, err := NewForConfig(context.Background(), runCtx)
 			t.CheckError(test.shouldErr, err)
 			if cfg != nil {
 				b, _t, d := runner.WithTimings(&test.expectedBuilder, test.expectedTester, test.expectedDeployer, test.cacheArtifacts)
@@ -463,7 +474,7 @@ func TestNewForConfig(t *testing.T) {
 				} else {
 					t.CheckNoError(err)
 					t.CheckTypeEquality(b, cfg.Pruner.Builder)
-					t.CheckTypeEquality(_t, cfg.Tester)
+					t.CheckTypeEquality(_t, cfg.tester)
 					t.CheckTypeEquality(d, cfg.deployer)
 				}
 			}
@@ -541,7 +552,7 @@ func TestTriggerCallbackAndIntents(t *testing.T) {
 					},
 				},
 			}
-			r, _ := NewForConfig(&runcontext.RunContext{
+			r, _ := NewForConfig(context.Background(), &runcontext.RunContext{
 				Opts:      opts,
 				Pipelines: runcontext.NewPipelines([]latestV1.Pipeline{pipeline}),
 			})
