@@ -18,17 +18,18 @@ package schema
 
 import (
 	"bytes"
+	"context"
 	"errors"
 	"fmt"
 	"io"
 	"regexp"
 	"strings"
 
-	"github.com/sirupsen/logrus"
 	"gopkg.in/yaml.v3"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/apiversion"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/errors"
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	latestV2 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v2"
@@ -73,6 +74,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta19"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta2"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta20"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta21"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta3"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta4"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/v2beta5"
@@ -144,6 +146,7 @@ var SchemaVersionsV1 = Versions{
 	{v2beta18.Version, v2beta18.NewSkaffoldConfig},
 	{v2beta19.Version, v2beta19.NewSkaffoldConfig},
 	{v2beta20.Version, v2beta20.NewSkaffoldConfig},
+	{v2beta21.Version, v2beta21.NewSkaffoldConfig},
 	{latestV1.Version, latestV1.NewSkaffoldConfig},
 }
 
@@ -372,7 +375,7 @@ func UpgradeTo(configs []util.VersionedConfig, toVersion string) ([]util.Version
 	if !upgradeNeeded {
 		return configs, nil
 	}
-	logrus.Debugf("config version out of date: upgrading to latest %q", toVersion)
+	log.Entry(context.TODO()).Debugf("config version out of date: upgrading to latest %q", toVersion)
 	var err error
 	var upgraded []util.VersionedConfig
 	for _, cfg := range configs {
