@@ -26,12 +26,13 @@ import (
 	"time"
 
 	"github.com/grpc-ecosystem/grpc-gateway/runtime"
-	"github.com/sirupsen/logrus"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/status"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
+	eventV2 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/event/v2"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	v2 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/server/v2"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/proto/v1"
@@ -130,6 +131,11 @@ func Initialize(opts config.SkaffoldOptions) (func() error, error) {
 		return callback, fmt.Errorf("starting HTTP server: %w", err)
 	}
 
+	// Optionally pause execution until endpoint hit
+	if opts.WaitForConnection {
+		eventV2.WaitForConnection()
+	}
+
 	return callback, nil
 }
 
@@ -140,9 +146,9 @@ func newGRPCServer(preferredPort int, usedPorts *util.PortSet) (func() error, in
 	}
 
 	if port != preferredPort {
-		logrus.Warnf("starting gRPC server on port %d. (%d is already in use)", port, preferredPort)
+		log.Entry(context.TODO()).Warnf("starting gRPC server on port %d. (%d is already in use)", port, preferredPort)
 	} else {
-		logrus.Infof("starting gRPC server on port %d", port)
+		log.Entry(context.TODO()).Infof("starting gRPC server on port %d", port)
 	}
 
 	s := grpc.NewServer()
@@ -167,7 +173,7 @@ func newGRPCServer(preferredPort int, usedPorts *util.PortSet) (func() error, in
 
 	go func() {
 		if err := s.Serve(l); err != nil {
-			logrus.Errorf("failed to start grpc server: %s", err)
+			log.Entry(context.TODO()).Errorf("failed to start grpc server: %s", err)
 		}
 	}()
 	return func() error {
@@ -207,9 +213,9 @@ func newHTTPServer(preferredPort, proxyPort int, usedPorts *util.PortSet) (func(
 	}
 
 	if port != preferredPort {
-		logrus.Warnf("starting gRPC HTTP server on port %d. (%d is already in use)", port, preferredPort)
+		log.Entry(context.TODO()).Warnf("starting gRPC HTTP server on port %d. (%d is already in use)", port, preferredPort)
 	} else {
-		logrus.Infof("starting gRPC HTTP server on port %d", port)
+		log.Entry(context.TODO()).Infof("starting gRPC HTTP server on port %d", port)
 	}
 
 	server := &http.Server{
