@@ -39,12 +39,12 @@ import (
 
 func TestNoTestDependencies(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
-		t.Override(&docker.NewAPIClient, func(docker.Config) (docker.LocalDaemon, error) { return nil, nil })
+		t.Override(&docker.NewAPIClient, func(context.Context, docker.Config) (docker.LocalDaemon, error) { return nil, nil })
 
 		cfg := &mockConfig{}
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
-		deps, err := tester.TestDependencies(&latestV1.Artifact{ImageName: "foo"})
+		deps, err := tester.TestDependencies(context.Background(), &latestV1.Artifact{ImageName: "foo"})
 		t.CheckNoError(err)
 		t.CheckEmpty(deps)
 	})
@@ -62,9 +62,9 @@ func TestTestDependencies(t *testing.T) {
 			},
 		}
 
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
-		deps, err := tester.TestDependencies(&latestV1.Artifact{ImageName: "foo"})
+		deps, err := tester.TestDependencies(context.Background(), &latestV1.Artifact{ImageName: "foo"})
 
 		expectedDeps := tmpDir.Paths("tests/test1.yaml", "tests/test2.yaml", "test3.yaml")
 		t.CheckNoError(err)
@@ -81,10 +81,10 @@ func TestWrongPattern(t *testing.T) {
 			}},
 		}
 
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
 
-		_, err = tester.TestDependencies(&latestV1.Artifact{ImageName: "image"})
+		_, err = tester.TestDependencies(context.Background(), &latestV1.Artifact{ImageName: "image"})
 		t.CheckError(true, err)
 		testEvent.InitializeState([]latestV1.Pipeline{{}})
 
@@ -100,7 +100,7 @@ func TestNoTest(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		cfg := &mockConfig{}
 
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
 
 		err = tester.Test(context.Background(), ioutil.Discard, nil)
@@ -139,7 +139,7 @@ func TestTestSuccess(t *testing.T) {
 		}
 
 		imagesAreLocal := true
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
 		t.CheckNoError(err)
 		err = tester.Test(context.Background(), ioutil.Discard, []graph.Artifact{{
 			ImageName: "image",
@@ -153,7 +153,7 @@ func TestTestSuccessRemoteImage(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		t.NewTempDir().Touch("test.yaml").Chdir()
 		t.Override(&util.DefaultExecCommand, testutil.CmdRun("container-structure-test test -v warn --image image:tag --config test.yaml"))
-		t.Override(&docker.NewAPIClient, func(docker.Config) (docker.LocalDaemon, error) {
+		t.Override(&docker.NewAPIClient, func(context.Context, docker.Config) (docker.LocalDaemon, error) {
 			return fakeLocalDaemon(&testutil.FakeAPIClient{}), nil
 		})
 
@@ -165,7 +165,7 @@ func TestTestSuccessRemoteImage(t *testing.T) {
 		}
 
 		imagesAreLocal := false
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
 		t.CheckNoError(err)
 
 		err = tester.Test(context.Background(), ioutil.Discard, []graph.Artifact{{
@@ -181,7 +181,7 @@ func TestTestFailureRemoteImage(t *testing.T) {
 	testutil.Run(t, "", func(t *testutil.T) {
 		t.NewTempDir().Touch("test.yaml").Chdir()
 		t.Override(&util.DefaultExecCommand, testutil.CmdRun("container-structure-test test -v warn --image image:tag --config test.yaml"))
-		t.Override(&docker.NewAPIClient, func(docker.Config) (docker.LocalDaemon, error) {
+		t.Override(&docker.NewAPIClient, func(context.Context, docker.Config) (docker.LocalDaemon, error) {
 			return fakeLocalDaemon(&testutil.FakeAPIClient{ErrImagePull: true}), nil
 		})
 
@@ -193,7 +193,7 @@ func TestTestFailureRemoteImage(t *testing.T) {
 		}
 
 		imagesAreLocal := false
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return imagesAreLocal, nil })
 		t.CheckNoError(err)
 
 		err = tester.Test(context.Background(), ioutil.Discard, []graph.Artifact{{
@@ -223,7 +223,7 @@ func TestTestFailure(t *testing.T) {
 			},
 		}
 
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
 
 		err = tester.Test(context.Background(), ioutil.Discard, []graph.Artifact{{
@@ -251,7 +251,7 @@ func TestTestMuted(t *testing.T) {
 		}
 
 		var buf bytes.Buffer
-		tester, err := NewTester(cfg, func(imageName string) (bool, error) { return true, nil })
+		tester, err := NewTester(context.Background(), cfg, func(imageName string) (bool, error) { return true, nil })
 		t.CheckNoError(err)
 
 		err = tester.Test(context.Background(), &buf, []graph.Artifact{{
